/// <reference types="node" />

import EventEmitter from 'events';
import { LogLevelDesc } from 'loglevel';
import { LogLevelNumbers } from 'loglevel';

/**
 * @public
 */
export declare interface AccountConfig {
    set(config: Partial<AccountConfigData>): Promise<void>;
}

/**
 * Account Configuration Data Response
 * @public
 */
export declare interface AccountConfigData<TUI = any> {
    /**
     * The SID of the Account that created the resource
     */
    accountSid: string;
    /**
     * An object that contains application-specific data
     */
    attributes: object;
    /**
     * Whether call recording is enabled
     */
    callRecordingEnabled: boolean;
    /**
     * The call recording webhook URL
     */
    callRecordingWebhookUrl: string | null;
    /**
     * A list of objects that contain the configuration for different channels
     */
    channelConfigs: Array<ChannelConfig> | null;
    /**
     * The SID of the chat service this user belongs to
     */
    chatServiceInstanceSid: string;
    /**
     * An object that contains the CRM attributes
     */
    crmAttributes: object | null;
    /**
     * A list of objects that contain the configurations for the Integrations supported in this configuration
     */
    integrations?: Array<IntegrationsConfig> | null;
    /**
     * The CRM Callback URL
     */
    crmCallbackUrl: string | null;
    /**
     * Whether CRM is present for Flex
     */
    crmEnabled: boolean | null;
    /**
     * The CRM Fallback URL
     */
    crmFallbackUrl: string | null;
    /**
     * The CRM type
     */
    crmType: string | null;
    /**
     * The ISO 8601 date and time in GMT when the Configuration resource was created
     */
    dateCreated: Date;
    /**
     * The ISO 8601 date and time in GMT when the Configuration resource was last updated
     */
    dateUpdated: Date;
    debuggerIntegration: DebuggerIntegration | null;
    flexUiStatusReport: FlexUiStatusReport | null;
    citrixVoiceVdi: CitrixVoiceVdi | null;
    /**
     * The SID of the Messaging service instance
     */
    messagingServiceInstanceSid: string | null;
    /**
     * The URL where the Flex instance is hosted
     */
    runtimeDomain: string;
    /**
     * The SID of the Flex service instance
     */
    flexServiceInstanceSid: string | null;
    /**
     * The SID of the Flex instance
     */
    flexInstanceSid: string | null;
    /**
     * The list of outbound call flows
     */
    outboundCallFlows: {
        [key: string]: OutboundFlows;
    } | null;
    /**
     * If flex-ui should load plugins
     */
    pluginServiceEnabled: boolean | null;
    /**
     * The plugin service attributes
     */
    pluginServiceAttributes: object | null;
    /**
     * The list of public attributes, which are visible to unauthenticated clients
     */
    publicAttributes: object;
    /**
     * The Flex Service version
     */
    serviceVersion: string | null;
    /**
     * The list of serverless service SIDs
     */
    serverlessServiceSids: Array<string> | null;
    /**
     * The status of the Flex onboarding. Can be: \'ok\', \'inprogress\',\'notstarted\'
     */
    status: string;
    /**
     * The TaskRouter SID of the offline activity
     */
    taskrouterOfflineActivitySid?: string;
    /**
     * The Skill description for TaskRouter workers
     */
    taskrouterSkills?: Array<SkillDefinition>;
    /**
     * The SID of the TaskRouter Target TaskQueue
     */
    taskrouterTargetTaskqueueSid: string;
    /**
     * The SID of the TaskRouter target Workflow
     */
    taskrouterTargetWorkflowSid: string;
    /**
     * The list of TaskRouter TaskQueues
     */
    taskrouterTaskqueues: Array<TaskQueue> | null;
    /**
     * The TaskRouter Worker attributes
     */
    taskrouterWorkerAttributes: {
        [key: string]: object;
    } | null;
    /**
     * The TaskRouter default channel capacities and availability for workers
     */
    taskrouterWorkerChannels: {
        [key: string]: WorkerChannel;
    } | null;
    /**
     * The SID of the TaskRouter Workspace
     */
    taskrouterWorkspaceSid: string;
    /**
     * The object that defines the NPM packages and versions to be used in Hosted Flex
     */
    uiDependencies: {
        [key: string]: string;
    } | null;
    /**
     * The object that describes Flex UI characteristics and settings
     */
    uiAttributes: TUI;
    /**
     * The primary language of the Flex UI
     */
    uiLanguage: string | null;
    /**
     * The Pinned UI version
     */
    uiVersion: string;
    queueStatsConfiguration: QueueStatsConfiguration | null;
    /**
     * The absolute URL of the Configuration resource
     */
    url: string;
}

/**
 * @public
 */
export declare type AccountConfigDataGetter = (sessionToken: string, options?: AccountConfigOptions) => Promise<AccountConfigData>;

/**
 * Account config keys
 * Possible keys from AccountConfigData structure
 * @public
 */
export declare type AccountConfigKeys = keyof AccountConfigData;

/**
 * @public
 */
export declare interface AccountConfigOptions {
    query?: {
        UiVersion?: string;
    };
    fetchPolicy?: "no-cache" | undefined;
}

/**
 * @public
 */
export declare type AccountConfigProvider = (sessionToken: string, options?: AccountConfigOptions) => Promise<AccountConfigData>;

/**
 * Account sid option
 * @public
 */
export declare interface AccountSidOption {
    /**
     * Account sid
     */
    accountSid: string;
}

/**
 * @public
 */
export declare const auth: (accountSid: string) => Authenticator;

/**
 * Authenticator
 * Provides methods for authentication
 *
 * @public
 */
export declare interface Authenticator {
    /**
     * Validates token
     * @param token - token to validate
     * @returns token information if valid
     */
    validateToken(token: string): Promise<TokenData>;
    /**
     * Refreshes token used by the SDK. Only applicable if Flex FA service is used
     * @param token - old token
     * @returns new token information
     */
    refreshToken(token: string): Promise<TokenRefreshResult>;
    /**
     * Returns identity provider url
     * @param config - config options
     * @returns idp url
     */
    getIdpUrl(config: IdpConfig): Promise<string>;
}

/**
 * Builds an Authentication object with the given account sid
 * @param accountSid - Account sid
 *
 * @public
 */
export declare type AuthenticatorFactory = (accountSid: string) => Authenticator;

/**
 * Configuration Service
 * Configuration for a Flex instance
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * Attachments configuration
 * @public
 */
export declare interface CbmAttachments {
    enabled: boolean;
    /**
     * Max number of attachments
     */
    number_of_attachments: number;
    /**
     * Max size of 1 attachment
     */
    max_file_size: number;
    /**
     * Max total size of attachments
     */
    max_total_file_size: number;
    /**
     * Accepted attachment extensions
     */
    accepted_extensions: Array<string>;
}

/**
 * Channel configuration object
 * @public
 */
export declare interface ChannelConfig {
    /**
     * Type of channel
     */
    address_type: string;
    cbm_attachments: CbmAttachments;
}

/**
 * ChannelData response object
 * @public
 */
export declare interface ChannelData {
    meta: ChannelDataMeta;
    channels: Array<ChannelDataChannels>;
}

/**
 * Channels data
 * @public
 */
export declare interface ChannelDataChannels {
    /**
     * Account sid
     */
    readonly account_sid?: string;
    /**
     * channel optimised routing
     */
    readonly channel_optimized_routing?: boolean;
    /**
     * Channel date creation
     */
    readonly date_created?: string;
    /**
     * Channel date updated
     */
    readonly date_updated?: string;
    /**
     * Channel friendly name
     */
    readonly friendly_name: string;
    links?: ChannelDataLinks;
    /**
     * task channel sid
     */
    readonly sid: string;
    /**
     * Channel unique name
     */
    readonly unique_name: string;
    /**
     * Workspace sid
     */
    readonly workspace_sid?: string;
    /**
     * task channel url
     */
    readonly url?: string;
}

/**
 * TaskRouter Service
 * Fetch queques stats for a Flex instance
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * Channels data next links
 * @public
 */
export declare interface ChannelDataLinks {
    /**
     * Workspace link
     */
    readonly workspace?: string;
}

/**
 * TaskRouter Service
 * Fetch queques stats for a Flex instance
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * Channels Api meta data
 * @public
 */
export declare interface ChannelDataMeta {
    /**
     * Api service url first page
     */
    readonly first_page_url?: string;
    /**
     * Channels
     */
    readonly key?: string;
    /**
     * Api service url next page
     */
    readonly next_page_url?: string;
    /**
     * Page number
     */
    readonly page?: number;
    /**
     * data per page
     */
    readonly page_size?: number;
    /**
     * Api service url previous page
     */
    readonly previous_page_url?: string;
    /**
     * Api service url
     */
    readonly url?: string;
}

/**
 * Configuration Service
 * Configuration for a Flex instance
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * Enable Voice on Citrix VDI
 * @public
 */
export declare interface CitrixVoiceVdi {
    enabled: boolean;
}

/**
 * Clear cached values, like Flex SDK configuration stored in Local Storage
 *
 * @public
 */
export declare type ClearCache = () => void;

/**
 * @public
 */
export declare const clearCache: () => void;

/**
 * @public
 */
export declare interface Client extends EventPublisher<ClientEvent> {
    readonly config: ClientConfigType;
    readonly roles: Array<Role>;
    readonly token: string;
    readonly insights: Insights;
    readonly virtualAgentData: VirtualAgentDataApi;
    readonly interactionContext: InteractionContextApi;
    destroy(): Promise<void>;
    updateToken(token: string): Promise<void>;
    createTelemetryClient<U extends object>(name: string): TelemetryClient<U>;
    profileConnector: ProfileConnector;
}

/**
 * @public
 */
export declare interface ClientConfigType {
    readonly account: AccountConfig;
}

/**
 * @public
 */
export declare enum ClientEvent {
    TokenExpired = "tokenExpired",
    TokenAboutToExpire = "tokenAboutToExpire",
    TokenUpdated = "tokenUpdated",
    TokenAutoUpdateFailed = "tokenAutoUpdateFailed",
    TokenMaxLifetimeReached = "tokenMaxLifetimeReached",
    ConnectionLost = "connectionLost",
    ConnectionRestored = "connectionRestored",
    Disconnected = "disconnected"
}

/**
 * Client options
 * @public
 */
export declare interface ClientOptions {
    /**
     * Session related options
     */
    readonly session: SessionOptions;
    /**
     * Logger related options
     */
    readonly logger: LoggerOptions;
    /**
     * Telemetry related options
     */
    readonly telemetry: TelemetryOptions;
    /**
     * Account config related options
     */
    readonly accountConfig: AccountConfigOptions;
    /**
     * Twilio Region ID, e.g. "us1", "ie1" etc
     */
    region: string;
    /**
     * Name of the app that is using Flex SDK, e.g. "My Custom App"
     */
    appName: string;
    /**
     * Version of the app that is using Flex SDK, e.g. "2.3"
     */
    appVersion: string;
}

/**
 * @public
 */
export declare type ClientProvider = (token: string, userOptions?: DeepPartial<ClientOptions>) => Promise<Client>;

/**
 * @public
 */
export declare const createClient: (token: string, userOptions?: DeepPartial<ClientOptions> | undefined) => Promise<Client>;

/**
 * Configuration Service
 * Configuration for a Flex instance
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * Debugger integration configuration
 * @public
 */
export declare interface DebuggerIntegration {
    console_errors_included?: boolean;
    enabled: boolean;
}

/**
 * @public
 */
export declare type DeepPartial<T> = {
    [P in keyof T]?: DeepPartial<T[P]> | T[P];
};

/**
 * Configuration Service
 * Configuration for a Flex instance
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * default configuration
 * @public
 */
export declare interface DefaultQueueStatsConfiguration {
    service_level_threshold?: number;
    short_abandoned_threshold?: number;
    reset_timezone?: string;
    reset_time?: string;
}

/**
 * Error code
 * @public
 */
export declare enum ErrorCode {
    /**
     * PermissionDenied error
     */
    PermissionDeniedError = 20003,
    /**
     * Invalid access token
     */
    InvalidAccessToken = 20101,
    /**
     * Access Token expired or expiration date invalid
     */
    AccessTokenExpired = 20104,
    /**
     * Twilsock rate limit exceeded
     */
    TooManyRequests = 20429,
    /**
     * Internal Server Error
     */
    InternalServerError = 20500,
    /**
     * Bad Gateway
     */
    BadGateway = 20502,
    /**
     * Service Unavailable
     */
    ServiceUnavailable = 20503,
    /**
     * Gateway Timeout
     */
    GatewayTimeout = 20504,
    /**
     * Authorization error
     */
    AuthorizationError = 45003,
    /**
     * Validation error
     */
    ValidationError = 45004,
    /**
     * Connection error
     */
    ConnectionError = 45011,
    /**
     * Unknown error thrown by a child SDK
     */
    SDK = 45500,
    /**
     * Unknown error
     */
    Unknown = 45501,
    /**
     * Access denied
     */
    Forbidden = 45502,
    /**
     * Invalid parameter value received as argument
     */
    InvalidParams = 45503,
    /**
     * Resource was not found
     */
    NotFound = 45504,
    /**
     * Function called in invalid state of the object
     */
    InvalidState = 45505,
    /**
     * Not able to reach the server
     */
    NetworkError = 45508,
    /**
     * TwilsockConnection error
     */
    TwilsockConnectionError = 45511,
    /**
     * DownstreamServiceError error
     */
    DownstreamServiceError = 45512,
    /**
     * Bad request error
     */
    BadRequest = 70002,
    /**
     * Invalid certificate
     */
    InvalidCertificate = 70251
}

/**
 * Error severity
 * @public
 */
export declare enum ErrorSeverity {
    Fatal = "fatal",
    Error = "error",
    Warning = "warning",
    Info = "info"
}

/**
 * @public
 */
export declare interface EventPublisher<E extends string | symbol, F = (...args: unknown[]) => void> {
    addListener(eventName: E, listener: F): this;
    removeListener(eventName: E, listener: F): this;
}

/**
 * Flex Feature Flags enable admins to opt-in to features that are currently in Pilot or Beta in Flex.
 * @public
 */
export declare interface FeaturesConfig {
    readonly features: Array<FeaturesList>;
    /**
     * Indicates if Ytica is active on the account
     */
    readonly insightsActive: boolean;
}

/**
 * @public
 */
export declare type FeaturesConfigDataGetter = (token: string) => Promise<FeaturesConfig>;

/**
 * Flex Features
 * Features for a Flex instance
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * List of features
 * @public
 */
export declare interface FeaturesList {
    /**
     * Feature description
     */
    readonly description: string;
    /**
     * Documentation URL
     */
    readonly docUrl: string;
    /**
     * Is feature enabled
     */
    readonly enabled: boolean;
    /**
     * Feature identifier
     */
    readonly id: string;
    /**
     * Feature name
     */
    readonly name: string;
    /**
     * Feature stage
     */
    readonly stage: string;
}

/**
 * Request body for POST /Profiles/Find endpoint.
 * @public
 */
export declare interface FindProfilesRequest {
    Attributes: Array<ProfileAttribute>;
    UniqueName: string;
    WriteIfNotFound?: boolean;
}

/**
 * Error thrown by Flex SDK
 * @public
 */
export declare class FlexSdkError extends Error {
    constructor(errorCode: ErrorCode, metadata?: FlexSdkErrorMetadata, details?: string, wrappedError?: Error);
    /**
     * Error code
     *
     * @readonly
     * @type {ErrorCode}
     */
    get code(): ErrorCode;
    /**
     * Detailed information about what caused the error
     *
     * @readonly
     * @type {string | undefined}
     */
    get details(): string | undefined;
    /**
     * Gets the wrapped Error that caused the exception
     *
     * @readonly
     * @returns {Error | undefined}
     */
    get wrappedError(): Error | undefined;
    /**
     * Gets the metadata about the error
     *
     * @readonly
     * @returns {FlexSdkErrorMetadata}
     */
    get metadata(): FlexSdkErrorMetadata;
}

/**
 * Metadata about error thrown by Flex SDK
 * @public
 */
export declare interface FlexSdkErrorMetadata {
    module?: string;
    resourceSid?: string;
    severity: ErrorSeverity;
    source?: string;
    translatedErrorCode?: ErrorCode;
    unhandled?: boolean;
}

/**
 * Configuration Service
 * Configuration for a Flex instance
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * Flex UI Status Report configuration
 * @public
 */
export declare interface FlexUiStatusReport {
    enabled: boolean;
}

/**
 * @public
 */
export declare interface GDTokenEvents {
    TokenUpdated: string;
    TokenUpdateFailed: string;
}

/**
 * @public
 */
export declare const getAccountConfig: (sessionToken: string, options?: AccountConfigOptions | undefined) => Promise<AccountConfigData<any>>;

/**
 * @public
 */
export declare const getFeaturesConfig: (token: string, uiVersion?: string | undefined) => Promise<FeaturesConfig>;

/**
 * @public
 */
export declare const getLogger: (name: string) => Logger;

/**
 * @public
 */
export declare const getPluginsConfig: PluginsConfigDataGetter;

/**
 * @public
 */
export declare const getPublicConfig: (option: (Without<AccountSidOption, RuntimeDomainOption> & RuntimeDomainOption) | (Without<RuntimeDomainOption, AccountSidOption> & AccountSidOption)) => Promise<PublicConfig>;

/**
 * @public
 */
export declare const getTaskChannels: (sessionToken: string, workspaceSid: string, queryParams?: string | undefined) => Promise<ChannelData>;

/**
 * @public
 */
export declare const getTaskQueues: (sessionToken: string, workspaceSid: string, queryParams?: string | undefined) => Promise<QueuesData>;

/**
 * @public
 */
export declare const getTwilioIdpUrl: (port?: string | undefined) => string;

/**
 * @public
 */
export declare const hasPermission: (permissionToCheck: string, tokenRoles: Array<Role>) => boolean;

/**
 * Profile Connector for Flex
 * Profile Connector addon for Flex
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * A single identifier that can identify a particular profile in a CDP.
 * @public
 */
export declare interface Identifier {
    /**
     * The CDP/CRM identifier key, in the casing that your service expects us to send along with it.
     */
    key: string;
    /**
     * The optional priority of this identifier, will correspond to the order of the identifiers that we query the CDP/CRM with. 1-indexed.
     */
    priority?: number;
    /**
     * the (optional) friendly name of this particular identifier. Used for presenting identifiers in a nice way in a number of different experiences.
     */
    friendly_name?: string;
}

/**
 * Response body for the GET /Identifiers endpoint.
 * @public
 */
export declare interface IdentifiersResponse {
    identifiers: Array<Identifier>;
}

/**
 * Identity provider configuration interface
 *
 * @public
 */
export declare interface IdpConfig {
    /**
     * redirect url where to return back from identity provider to log in to Flex
     */
    redirectUrl: string;
}

/**
 * @public
 */
export declare interface Insights {
    readonly events: GDTokenEvents;
    eventEmitter: EventEmitter;
    getInsightsRolesForUser: () => Promise<InsightsUserRoles>;
    generateGoodDataSession: () => Promise<SessionSuccess>;
    destroy: () => void;
}

/**
 * Insights Service
 * Flex Insights Apis
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * Response schema for the array of Insights Roles for the User
 * @public
 */
export declare interface InsightsUserRoles {
    roles: Array<string>;
}

/**
 * Configuration Service
 * Configuration for a Flex instance
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * Integrations config
 * @public
 */
export declare interface IntegrationsConfig {
    name: string;
    type: string;
    active: boolean;
    config: object;
    /**
     * Url of logo
     */
    logo?: string;
    author?: string;
}

/**
 * Interaction Context Service
 * Interaction Context Service
 *
 * The version of the OpenAPI document: 1.0.0
 * Contact: flex-sdk@twilio.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * Response schema for the Interaction Context endpoint
 * @public
 */
export declare interface InteractionContext {
    account_sid: string;
    sid: string;
    channel: string;
    attributes?: object;
    date_created?: Date;
    date_updated?: Date;
    created_by: string;
    last_update_by?: string;
    version: number;
}

/**
 * @public
 */
export declare interface InteractionContextApi {
    getInteractionContext: (lookupSid: string, agentViewable?: boolean) => Promise<InteractionContext>;
    getProfileConnector: (taskSid: string) => Promise<ProfileConnectorData>;
    createInteractionContext: (channel: string, formData: string) => Promise<InteractionContext>;
    addLookupSidToContext: (lookupSid: string, contextSid: string) => Promise<Message>;
}

/**
 * Logger
 * @public
 */
export declare interface Logger {
    trace: (...log: unknown[]) => void;
    debug: (...log: unknown[]) => void;
    log: (...log: unknown[]) => void;
    info: (...log: unknown[]) => void;
    warn: (...log: unknown[]) => void;
    error: (...log: unknown[]) => void;
    setLevel: (level: LoggerLevel) => void;
    getLevel: () => LoggerLevelNumbers;
}

/**
 * Logger Factory
 * @public
 */
export declare type LoggerFactory<TName = LoggerName> = (name: TName) => Logger;

/**
 * Logger level
 * @public
 */
export declare type LoggerLevel = LogLevelDesc;

/**
 * @public
 */
export declare type LoggerLevelNumbers = LogLevelNumbers;

/**
 * @public
 */
export declare enum LoggerName {
    Client = "flex:Client",
    Error = "flex:Error",
    Retry = "flex:Retry",
    Session = "flex:Session",
    Twilsock = "flex:Twilsock",
    Auth = "flex:Auth",
    Config = "flex:Config",
    Sync = "flex:Sync",
    SyncAdapter = "flex:SyncAdapter",
    QueueStats = "flex:QueueStats",
    Storage = "flex:Storage",
    Insights = "flex:Insights",
    ProfileConnector = "flex:ProfileConnector",
    VirtualAgentData = "flex:VirtualAgentData",
    InteractionContext = "flex:InteractionContext"
}

/**
 * Logger options
 * @public
 */
export declare interface LoggerOptions {
    level: LoggerLevel;
}

/**
 * Interaction Context Service
 * Interaction Context Service
 *
 * The version of the OpenAPI document: 1.0.0
 * Contact: flex-sdk@twilio.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * Message related to Creating Context
 * @public
 */
export declare interface Message {
    message: string;
}

/**
 * Configuration Service
 * Configuration for a Flex instance
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * Outbound flows
 * @public
 */
export declare interface OutboundFlows {
    /**
     * Enable flag
     */
    enabled: boolean;
    /**
     * Phone number
     */
    caller_id: string;
    /**
     * Queue sid
     */
    queue_sid: string;
    /**
     * Country code
     */
    location: string;
    /**
     * Workflow sid
     */
    workflow_sid: string;
}

/**
 * Flex Plugins
 * Plugin defenitions for a Flex instance
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * Plugin defenition
 * @public
 */
declare interface Plugin_2 {
    /**
     * Plugin description
     */
    readonly name: string;
    /**
     * Flex instance version
     */
    readonly flexVersion?: string;
    /**
     * Source code for the plugin
     */
    readonly src: string;
    /**
     * Plugin version
     */
    readonly version: string;
    /**
     * Phase of the plugin
     */
    readonly phase: number;
    /**
     * Plugin creator
     */
    readonly provider?: string;
    /**
     * Plugin integrity
     */
    readonly integrity?: string;
    /**
     * Plugin sid
     */
    readonly pluginSid?: string;
    /**
     * Plugin version sid
     */
    readonly pluginVersionSid?: string;
    /**
     * Plugin configuration sid
     */
    readonly configurationSid?: string;
    /**
     * Plugin release sid
     */
    readonly releaseSid?: string;
}
export { Plugin_2 as Plugin }

/**
 * @public
 */
export declare type PluginsConfigDataGetter = (token: string, queryParams?: string) => Promise<Array<Plugin_2>>;

/**
 * This is the opinionated view Twilio has of a CDP profile.
 * @public
 */
export declare interface Profile {
    /**
     * Unique Profile Mapping Identifier
     */
    sid: string;
    /**
     * The type of the profile:
     */
    type: string | null;
    /**
     * The given name of the profile, non-optional. Maps to \'first name\' in the US/Canada.  Either \'business_name\' or a combination of \'given_name\' and \'family_name\' is required.
     */
    given_name?: string | null;
    /**
     * Single additional name field. Maps to \'middle name\' in the United States.
     */
    additional_name?: string | null;
    /**
     * The family name of the profile, non-optional. Maps to \'last name\' in the US/Canada.  Either \'business_name\' or a combination of \'given_name\' and \'family_name\' is required.
     */
    family_name?: string | null;
    /**
     * Business name associated with this profile. Either \'business_name\' or a combination of \'given_name\' and \'family_name\' is required.
     */
    business_name?: string | null;
    /**
     * Freeform type field for what type of contact this is.
     */
    contact_type?: string | null;
    /**
     * The email address of the profile.
     */
    email_address?: string | null;
    /**
     * The phone number of the profile.
     */
    phone_number?: string | null;
    /**
     * The date this profile record was created. Can include time as well, not required. Format should be RFC 3339 https://www.rfc-editor.org/rfc/rfc3339#section-5.6
     */
    date_created?: string | null;
    /**
     * The date this profile record was last updated. Can include time as well, not required. Format should be RFC 3339 https://www.rfc-editor.org/rfc/rfc3339#section-5.6.
     */
    date_updated?: string | null;
    /**
     * Fully qualified url of the optional profile image (used for things like an avatar, biz logo, etc.).
     */
    profile_image_url?: string | null;
    /**
     * Optional list of additional contacts.
     */
    additional_contacts?: Array<ProfileContact>;
    /**
     * Optional list of additional contacts.
     */
    addresses?: Array<ProfileAddress>;
    /**
     * To add more information about the profile like membership level, gender, birth date, or whatever else you would like to include should not be protected information.
     */
    additional_attributes?: {
        [key: string]: string;
    };
}

/**
 * Profile Connector for Flex
 * Profile Connector addon for Flex
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * An object representing address information for a profile.
 * @public
 */
export declare interface ProfileAddress {
    /**
     * A unique ID for the address resource. Used for linking addresses and contacts together.
     */
    id: string | null;
    /**
     * The type of address this is, eg \'Business\', \'Home\', \'Secret Lair\', etc.
     */
    type: string | null;
    /**
     * First address line of the profile.
     */
    address_1?: string | null;
    /**
     * second address line of the profile.
     */
    address_2?: string | null;
    /**
     * third address line of the profile.
     */
    address_3?: string | null;
    /**
     * City of the profile.
     */
    city?: string | null;
    /**
     * Postal/Zip code of the profile.
     */
    zip_code?: string | null;
    /**
     * State/Province of the profile.
     */
    state?: string | null;
    /**
     * Country of the profile.
     */
    country?: string | null;
    /**
     * Optional additional list of fields for unspecified address information. Could be something like \'street_direction\' etc.
     */
    additional_fields?: {
        [key: string]: string;
    };
}

/**
 * Profile Connector for Flex
 * Profile Connector addon for Flex
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * The properties of the Participant to create
 * @public
 */
export declare interface ProfileAttribute {
    /**
     * The key of the attribute.
     */
    key: string;
    /**
     * The value of the attribute.
     */
    value: string;
}

/**
 * @public
 */
export declare interface ProfileConnector {
    findProfileByUniqueId(uniqueIdentifier: string, uniqueName: string): Promise<Profile>;
    findProfileByIdentifiers(findProfilesRequest: FindProfilesRequest): Promise<ProfilesResponse>;
    getIdentifiers(uniqueName: string): Promise<IdentifiersResponse>;
    getTraits(uniqueName: string): Promise<TraitsResponse>;
}

/**
 * @public
 */
export declare interface ProfileConnectorData {
    profileConnectSid?: string;
    connectorName?: string;
    taskSid: string;
}

/**
 * Profile Connector for Flex
 * Profile Connector addon for Flex
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * An object representing contact information for a profile.
 * @public
 */
export declare interface ProfileContact {
    /**
     * Freeform type field for what type of contact this is.
     */
    type?: string | null;
    /**
     * The given name of the profile, non-optional. Maps to \'first name\' in the US/Canada.  Either \'business_name\' or a combination of \'given_name\' and \'family_name\' is required.
     */
    given_name?: string | null;
    /**
     * Single additional name field. Maps to \'middle name\' in the United States.
     */
    additional_name?: string | null;
    /**
     * The family name of the profile, non-optional. Maps to \'last name\' in the US/Canada.  Either \'business_name\' or a combination of \'given_name\' and \'family_name\' is required.
     */
    family_name?: string | null;
    /**
     * Business name associated with this profile. Either \'business_name\' or a combination of \'given_name\' and \'family_name\' is required.
     */
    business_name?: string | null;
    /**
     * The email address of the profile.
     */
    email_address?: string | null;
    /**
     * The phone number of the profile.
     */
    phone_number?: string | null;
    /**
     * Optional association of this contact to a particular address resource
     */
    address_id?: string | null;
    /**
     * Optional additional list of fields for unspecified contact information. Could be something like \'ip_address\' for an IoT device, etc.
     */
    additional_fields?: {
        [key: string]: string;
    };
}

/**
 * Response body for the POST Resolve endpoint.
 * @public
 */
export declare interface ProfilesResponse {
    profiles: Array<RankedProfile>;
}

/**
 * Public configuration object
 * @public
 */
export declare interface PublicConfig {
    /**
     * Runtime domain
     */
    runtimeDomain: string;
    publicAttributes: PublicConfigAttributes | null;
    /**
     * Account SID (may be encrypted)
     */
    accountSid: string;
}

/**
 * Configuration Service
 * Configuration for a Flex instance
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * Public configuration attributes
 * @public
 */
export declare interface PublicConfigAttributes {
    [key: string]: object | unknown;
    /**
     * Whether the SSO flow needs to be launched in a popup window
     */
    loginPopup?: boolean;
}

/**
 * Public Config Provider
 * @public
 */
export declare type PublicConfigProvider = (option: XOR<AccountSidOption, RuntimeDomainOption>) => Promise<PublicConfig>;

/**
 * Configuration Service
 * Configuration for a Flex instance
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * Queue channel configuration object
 * @public
 */
export declare interface QueueChannelConfiguration {
    /**
     * Queue sid
     */
    queue_sid: string;
    channel_sid: string;
    service_level_threshold: number;
    short_abandoned_threshold: number;
}

/**
 * Configuration Service
 * Configuration for a Flex instance
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * Queue configuration object
 * @public
 */
export declare interface QueueConfiguration {
    queue_sid: string;
    reset_timezone: string;
    reset_time: string;
}

/**
 * QueuesData response object
 * @public
 */
export declare interface QueuesData {
    meta: QueuesDataMeta;
    task_queues: Array<QueuesDataTaskQueues>;
}

/**
 * TaskRouter Service
 * Fetch queques stats for a Flex instance
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * Queues data links
 * @public
 */
export declare interface QueuesDataLinks {
    /**
     * Assignment activity link
     */
    readonly assignment_activity?: string;
    /**
     * Workspace link
     */
    readonly cumulative_statistics?: string;
    /**
     * Cumulative statistics link
     */
    readonly list_statistics?: string;
    /**
     * Real time statistics link
     */
    readonly real_time_statistics?: string;
    /**
     * Reservation activity link
     */
    readonly reservation_activity?: string;
    /**
     * Statistics link
     */
    readonly statistics?: string;
    /**
     * Workspace link
     */
    readonly workspace?: string;
}

/**
 * TaskRouter Service
 * Fetch queques stats for a Flex instance
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * Queues Api meta data
 * @public
 */
export declare interface QueuesDataMeta {
    /**
     * Api service url first page
     */
    readonly first_page_url?: string;
    /**
     * queques
     */
    readonly key?: string;
    /**
     * Api service url next page
     */
    readonly next_page_url?: string;
    /**
     * Page number
     */
    readonly page?: number;
    /**
     * data per page
     */
    readonly page_size?: number;
    /**
     * Api service url previous page
     */
    readonly previous_page_url?: string;
    /**
     * Api service url
     */
    readonly url?: string;
}

/**
 * Queues data
 * @public
 */
export declare interface QueuesDataTaskQueues {
    /**
     * Account sid
     */
    readonly account_sid?: string;
    /**
     * Assignment activity name
     */
    readonly assignment_activity_name?: string;
    /**
     * Assignment activity sid
     */
    readonly assignment_activity_sid?: string;
    /**
     * Channel date creation
     */
    readonly date_created: string;
    /**
     * Channel date updated
     */
    readonly date_updated: string;
    /**
     * Channel friendly name
     */
    readonly friendly_name: string;
    links?: QueuesDataLinks;
    /**
     * task channel sid
     */
    readonly sid: string;
    /**
     * Max reserved workers
     */
    readonly max_reserved_workers?: string;
    /**
     * Reservation activity name
     */
    readonly reservation_activity_name?: string;
    /**
     * Reservation activity sid
     */
    readonly reservation_activity_sid?: string;
    /**
     * Target workers
     */
    readonly target_workers?: string;
    /**
     * Workspace sid
     */
    readonly workspace_sid?: string;
    /**
     * Task order
     */
    readonly task_order?: string;
    /**
     * url
     */
    readonly url?: string;
}

/**
 * @public
 */
export declare type QueueStatsChannelsDataGetter = (sessionToken: string, workspaceSid: string, queryParams?: string) => Promise<ChannelData>;

/**
 * Queue stats configuration object
 * @public
 */
export declare interface QueueStatsConfiguration {
    default: DefaultQueueStatsConfiguration;
    /**
     * List of Queue Configurations for an account
     */
    queue_configurations: Array<QueueConfiguration>;
    /**
     * List of Queue Channel Configurations for an account
     */
    queue_channel_configurations: Array<QueueChannelConfiguration>;
}

/**
 * @public
 */
export declare type QueueStatsQueuesDataGetter = (sessionToken: string, workspaceSid: string, queryParams?: string) => Promise<QueuesData>;

/**
 * A profile entry augmented with an optional \'match percentage\' of how close the match was to the given attributes.
 * @public
 */
export declare interface RankedProfile {
    profile: Profile;
    /**
     * This is an optional number between 0 and 100 (inclusive) that indicates how close of a match this profile was to the provided attributes.
     */
    match_percentage?: number;
    /**
     * This is a string that indicates the status of the profile. It can be one of \'unknown\', or \'identified\'.
     */
    status?: RankedProfile.StatusEnum;
}

/**
 * @public
 */
export declare namespace RankedProfile {
    export type StatusEnum = "unknown" | "identified";
    const StatusEnum: {
        Unknown: StatusEnum;
        Identified: StatusEnum;
    };
}

/**
 * FederatedAuth Service
 * Authentication for a Flex instance
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * Role of the user
 * @public
 */
export declare enum Role {
    Guest = "guest",
    Agent = "agent",
    Admin = "admin",
    Supervisor = "supervisor",
    FlexReadqueuestats = "flex.readqueuestats",
    FlexReadteams = "flex.readteams",
    FlexEditstatus = "flex.editstatus",
    FlexEditskills = "flex.editskills",
    FlexMonitorchatcall = "flex.monitorchatcall",
    FlexReadadmin = "flex.readadmin",
    FlexLead = "flex.lead",
    FlexQualityanalyst = "flex.qualityanalyst",
    FlexReadonlyadmin = "flex.readonlyadmin"
}

/**
 * Runtime domain option
 * @public
 */
export declare interface RuntimeDomainOption {
    /**
     * Runtime domain
     */
    runtimeDomain: string;
}

/**
 * @public
 */
export declare interface SessionOptions {
    readonly autoUpdateToken: boolean;
}

/**
 * Insights Service
 * Flex Insights Apis
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * Schema for GoodData Session successful response
 * @public
 */
export declare interface SessionSuccess {
    /**
     * Workspace Id
     */
    workspaceId: string;
    /**
     * Session expiry timestamp
     */
    sessionExpiry: string;
    /**
     * Session Id
     */
    sessionId: string;
    /**
     * Ytica Analytics dashboard URL
     */
    baseUrl?: string;
}

/**
 * @public
 */
export declare const setWorkerConfig: (sessionToken: string, workerConfig: string) => Promise<WorkerConfigResponse>;

/**
 * Configuration Service
 * Configuration for a Flex instance
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * Taskrouter skill definition
 * @public
 */
export declare interface SkillDefinition {
    /**
     * Skill name
     */
    name: string;
    /**
     * Skill type, if true value can be given between min and max
     */
    multivalue: boolean;
    /**
     * minimum value
     */
    minimum?: number;
    /**
     * maximum value
     */
    maximum?: number;
}

/**
 * Configuration Service
 * Configuration for a Flex instance
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * Task queues used for Transfers
 * @public
 */
export declare interface TaskQueue {
    /**
     * TaskQueue Sid
     */
    sid: string;
    /**
     * TaskQueue available as target
     */
    targettable: boolean;
}

/**
 * Telemetry client
 * @public
 */
export declare interface TelemetryClient<U extends object = object> {
    /**
     * Name of the type of client attributes
     */
    name: string;
    /**
     * Session data
     */
    sessionData?: U;
    /**
     * Creates event group
     * @param name - group name
     */
    createEventGroup<T>(name?: string): TelemetryEventGroup<T>;
    setSessionData(sessionData: U): Promise<void>;
}

/**
 * Event for error specific events
 * @public
 */
export declare interface TelemetryErrorEvent extends TelemetryEvent {
    /**
     * Error payload
     */
    error: {
        /**
         * Error code
         */
        code: number;
        /**
         * Whether the error should be reported to the debugger
         */
        debugger: boolean;
        /**
         * Description of the error
         */
        description?: string;
        /**
         * Error message
         */
        message: string;
        /**
         * Code area, module or component that reported the error
         */
        module?: string;
        /**
         * Name of the plugin where the error originated from
         */
        plugin?: string;
        /**
         * Plugin version that caused the error
         */
        pluginVersion?: string;
        /**
         * Name of the reporter
         */
        reporter: string;
        /**
         * Resource SID that the error correlates with
         */
        resourceSid?: string;
        /**
         * Severity of the error
         */
        severity: "fatal" | "error" | "warning" | "info";
        /**
         * Source where the error originated, e.g. when thrown by some other SDK
         */
        source: string;
        /**
         * Stack Trace of the error
         */
        stackTrace?: string;
        /**
         * Whether it's an unhandled error
         */
        unhandled?: boolean;
        /**
         * Error message of the error that was wrapped
         */
        wrappedErrorMessage?: string;
        /**
         * Error code of the error that was wrapped
         */
        wrappedErrorCode?: number;
    };
}

/**
 * Event base properties
 * @public
 */
export declare interface TelemetryEvent {
    /**
     * Event name
     */
    eventName: string;
    /**
     * Source that initiated the event
     */
    eventSource?: string;
}

/**
 * Wrapper for a list of events and common fields for all the events
 * @public
 */
export declare interface TelemetryEventGroup<T> {
    /**
     * Group name
     */
    name?: string;
    /**
     * TelemetryClientAttributes
     */
    telemetryClient: TelemetryClient<object>;
    /**
     * Add events to group
     * @param events - Events to be added
     */
    addEvents(...events: (T & TelemetryEvent)[]): Promise<TelemetryProcessingResult>;
    /**
     * Add error event to group
     * @param event - ErrorEvent to be added
     */
    addErrorEvent(event: TelemetryErrorEvent): Promise<TelemetryProcessingResult>;
}

/**
 * @public
 */
export declare type TelemetryOptions = {
    /**
     * Set to `false` to opt-out from submitting errors via telemetry
     */
    readonly reportErrors: boolean;
};

/**
 * @public
 */
export declare type TelemetryProcessingResult = {
    eventsSucceeded: number;
    eventsFailed: number;
    eventsNotProcessed: number;
};

/**
 * Token information
 *
 * @public
 */
export declare type TokenData = {
    roles: Array<Role>;
    valid: boolean;
    dateExpired: Date;
    identity: string;
};

/**
 * Object returned by refreshToken()
 *
 * @public
 */
export declare type TokenRefreshResult = {
    token: string;
    dateExpired: Date;
};

/**
 * Profile Connector for Flex
 * Profile Connector addon for Flex
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * A single trait mapping.
 * @public
 */
export declare interface Trait {
    /**
     * The CDP/CRM property, in it\'s original casing.
     */
    from: string;
    /**
     * The field on our profile data model that the \'from\' field maps to. Can be a many to 1 mapping for additional_attributes. For arrays, will be represented with array syntax. For Example \'addresses[0].address_1\'
     */
    to?: string;
    /**
     * This is a future looking array of categories that a particular trait will be associated with, user-defined. All fields will have \'default\' as a category for now.
     */
    categories?: Array<string>;
    /**
     * the (optional) friendly name of this particular trait. Used almost exclusively in conjunction with the additional_attributes mappings, so that we have the ability to communicate a nicer looking name for this.
     */
    friendly_name?: string;
}

/**
 * Response body for the GET /Traits endpoint.
 * @public
 */
export declare interface TraitsResponse {
    traits: Array<Trait>;
}

/**
 * Returns Twilio IDP url
 * @param port - port
 *
 * @public
 */
export declare type TwilioIdpUrlFunction = (port?: string) => string;

/**
 * @public
 */
export declare const version: string;

/**
 * Response schema for the VA endpoint
 * @public
 */
export declare interface VirtualAgentData {
    sentences: Array<VirtualAgentDataSentences>;
}

/**
 * @public
 */
export declare interface VirtualAgentDataApi {
    getV1VirtualAgentData: (contextLookupSid: string) => Promise<VirtualAgentData>;
}

/**
 * Fetch data for Virtual Agent
 * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
 *
 * The version of the OpenAPI document: 1.0
 * Contact: flex-sdk@twilio.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * Schema for VirtualAgentData Sentences
 * @public
 */
export declare interface VirtualAgentDataSentences {
    sentence_index: number;
    start_time: string;
    role: string;
    transcript: string;
}

/**
 * Without
 * Constructs a type by forcing all properties from T that are not assignable to U to be undefined
 * @public
 */
export declare type Without<T, U> = {
    [P in Exclude<keyof T, keyof U>]?: never;
};

/**
 * Configuration Service
 * Configuration for a Flex instance
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * Default Worker attribute settings
 * @public
 */
export declare interface WorkerChannel {
    /**
     * Unique name of the TaskChannel associated to this WorkerChannel
     */
    name: string;
    /**
     * Default capacity value
     */
    capacity: number;
    /**
     * Default availability
     */
    availability: boolean;
}

/**
 * @public
 */
export declare type WorkerConfigDataSetter = (sessionToken: string, config: string) => Promise<WorkerConfigResponse>;

/**
 * worker config request data
 * @public
 */
export declare interface WorkerConfigResponse {
    /**
     * Worker SID
     */
    readonly sid: string;
    /**
     * Workspace SID
     */
    readonly workspace_sid: string;
    /**
     * Activity SID
     */
    readonly activity_sid?: string;
    attributes?: WorkerConfigResponseAttributes;
    /**
     * Worker capacities
     */
    readonly capacities?: string;
    /**
     * Flex account SID
     */
    readonly account_sid: string;
    /**
     * API url
     */
    readonly url?: string;
}

/**
 * Worker attributes
 * @public
 */
export declare interface WorkerConfigResponseAttributes {
    /**
     * Contact uri
     */
    readonly contact_uri?: string;
    /**
     * email
     */
    readonly email?: string;
    disabled_skills?: WorkerConfigResponseAttributesDisabledSkills;
    /**
     * Full name
     */
    readonly full_name?: string;
    /**
     * image url
     */
    readonly image_url?: string;
    /**
     * roles
     */
    readonly roles?: Array<string>;
    routing?: WorkerConfigResponseAttributesRouting;
}

/**
 * Worker attributes update
 * Worker attributes update for a Flex instance
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * Disabled skills
 * @public
 */
export declare interface WorkerConfigResponseAttributesDisabledSkills {
    /**
     * Disabled roles
     */
    readonly levels?: object;
    /**
     * Disabled skills
     */
    readonly skills?: Array<string>;
}

/**
 * Worker attributes update
 * Worker attributes update for a Flex instance
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * routing
 * @public
 */
export declare interface WorkerConfigResponseAttributesRouting {
    /**
     * routing levels
     */
    readonly levels?: object;
    /**
     * routing skills
     */
    readonly skills?: Array<string>;
}

/**
 * XOR
 * Constructs a type that requires type T or U, but not both
 * @public
 */
export declare type XOR<T, U> = T | U extends object ? (Without<T, U> & U) | (Without<U, T> & T) : T | U;

export { }
